@@ -2,7 +2,7 @@ package Tie::Hash::Attribute;
 use 5.006;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 our @ISA = 'Tie::Hash';
 
@@ -29,9 +29,8 @@ sub _mk_str {
         my $val = defined($hash->{$key}) ? $hash->{$key} : '';
         $val  = _stringify( $val )  if ref $val eq 'HASH';
         $val  = _rotate( $val )     if ref $val eq 'ARRAY';
-        $str .= qq($key="$val" )    unless $val =~ /^$/;
+        $str .= qq( $key="$val")    unless $val =~ /^$/;
     }
-    chop $str;
     return $str;
 }
 
@@ -45,19 +44,21 @@ sub _rotate {
 sub _stringify {
     my $hash = shift;
 
-    return join('; ', map { my $val;
+    my @vals = map { my $val;
 
         if (ref $hash->{$_} eq 'ARRAY') {
             $val = _rotate( $hash->{$_} );
         } elsif (ref $hash->{$_} eq 'HASH') {
-            ($val) = keys %{ $hash->{$_} };
+            ($val) = sort keys %{ $hash->{$_} };
         } else {
             $val = $hash->{$_};
         }
 
         join( ': ', $_, $val);
 
-    } sort keys %$hash) . ';';
+    } sort keys %$hash;
+
+    return join( '; ', @vals ) . (@vals > 1 ? ';' : '');
 }
 
 1;
@@ -96,20 +97,70 @@ Tie::Hash::Attribute - Print hash values as rotating HTML attributes.
     # style="align: left; color: green;"',
     # style="align: right; color: red;"',
 
+  # or emit all attributes at once
+  tie my %tr_tag, 'Tie::Hash::Attribute';
+  %tr_tag = ( style => { color => [qw(red blue green)] } );
+  print scalar %tr_tag;
+    # style="align: right; color: red;"
+
 =head1 DESCRIPTION
 
 This module will translate the keys and values into HTML tag attributes.
 You just need to provide the tags.
 
-Hash values can be scalars, arrays, hashes or hashes of hashes. Going "too deep"
-will gracefully stop at the second nested key, which will use the third as its value:
+Hash values can be scalars, arrays, hashes or hashes of hashes.
+
+To emit values as an HTML attribute string, fetch the key with
+a dash prepended to it:
+
+  %hash = ( foo => 1, bar => 2, baz => 3);
+
+  print $hash{foo};     # returns original value
+  print $hash{-foo};    # returns value as HTML attribute string
+
+Or access the entire hash as a scalar:
+
+  print scalar %hash;
+
+You can use this to to aide in the creation of HTML tags:
+
+  print '<table>';
+  for my $row (@rows) {
+      printf '<tr%s>', scalar %tr;
+      for my $col (@$row) {
+          printf '<td%s>%s</td>', scalar %td, $col;
+      }
+      print '</tr>';
+  }
+
+The decision on which style to apply to a row is deferred to
+the tied hash.  Just assign an array reference to the key and
+each value will be rotated.
+
+  %tr_tag = ( class => [qw( odd even )] );
+
+=head1 BUGS AND LIMITATIONS
+
+Assignment stops at the second nested key, which will use the
+third as its value:
 
   $tag{foo}{1st}{2nd}{3rd} = '4th';
   print $tag{-foo}, "\n";
 
   # yields 1st="2nd: 3rd;"
 
-=head1 BUGS AND LIMITATIONS
+This is an intended limitation. If there are other keys in the
+second nested hash, then the first key in alphabetical order wins.
+
+There are other limitations that will be corrected over a short time:
+
+=over 4
+
+=item * Need to apply correct encoding to keys.
+
+=item * Need to detect when " is in a value.
+
+=back
 
 Please report any bugs or feature requests to either
 
@@ -145,6 +196,14 @@ You can also look for information at:
 
 =back
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<http://www.w3.org/TR/html5/syntax.html#attributes-0>
+
+=back
+
 =head1 AUTHOR
 
 Jeff Anderson, C<< <jeffa at cpan.org> >>
